Crate libspnav

Crate libspnav 

All the functions in this crate have identical functionality to the underlying libspnav library, with the key change being the use of a Rust enum to represent the events returned by wait_event() safely.

Structs

ButtonEvent
MotionEvent

Enums

Error
Event
EventType

Functions

close
fd
open
poll_event
remove_events
sensitivity
wait_event

Type Aliases

Result